# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.form_api import FormApi


class TestFormApi(unittest.TestCase):
    """FormApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FormApi()

    def tearDown(self) -> None:
        pass

    def test_create_form_response(self) -> None:
        """Test case for create_form_response

        """
        pass

    def test_create_form_response_by_identifier(self) -> None:
        """Test case for create_form_response_by_identifier

        """
        pass


if __name__ == '__main__':
    unittest.main()
