# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.event_types_api import EventTypesApi


class TestEventTypesApi(unittest.TestCase):
    """EventTypesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventTypesApi()

    def tearDown(self) -> None:
        pass

    def test_create_event_type(self) -> None:
        """Test case for create_event_type

        """
        pass

    def test_get_event_type(self) -> None:
        """Test case for get_event_type

        """
        pass

    def test_list_event_types(self) -> None:
        """Test case for list_event_types

        """
        pass

    def test_list_event_types_for_control_room(self) -> None:
        """Test case for list_event_types_for_control_room

        """
        pass

    def test_update_event_type(self) -> None:
        """Test case for update_event_type

        """
        pass


if __name__ == '__main__':
    unittest.main()
