# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.asset_types_api import AssetTypesApi


class TestAssetTypesApi(unittest.TestCase):
    """AssetTypesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AssetTypesApi()

    def tearDown(self) -> None:
        pass

    def test_assign_asset_type_to_control_room(self) -> None:
        """Test case for assign_asset_type_to_control_room

        """
        pass

    def test_create_asset_type(self) -> None:
        """Test case for create_asset_type

        """
        pass

    def test_get_asset_map_view(self) -> None:
        """Test case for get_asset_map_view

        """
        pass

    def test_get_asset_settings(self) -> None:
        """Test case for get_asset_settings

        """
        pass

    def test_get_asset_table_view(self) -> None:
        """Test case for get_asset_table_view

        """
        pass

    def test_get_asset_type(self) -> None:
        """Test case for get_asset_type

        """
        pass

    def test_list_asset_types(self) -> None:
        """Test case for list_asset_types

        """
        pass

    def test_list_asset_types_for_control_room(self) -> None:
        """Test case for list_asset_types_for_control_room

        """
        pass

    def test_update_asset_map_view(self) -> None:
        """Test case for update_asset_map_view

        """
        pass

    def test_update_asset_table_view(self) -> None:
        """Test case for update_asset_table_view

        """
        pass

    def test_update_asset_type(self) -> None:
        """Test case for update_asset_type

        """
        pass


if __name__ == '__main__':
    unittest.main()
