# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.attachments_api import AttachmentsApi


class TestAttachmentsApi(unittest.TestCase):
    """AttachmentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AttachmentsApi()

    def tearDown(self) -> None:
        pass

    def test_add_asset_attachments(self) -> None:
        """Test case for add_asset_attachments

        """
        pass

    def test_add_form_response_attachments(self) -> None:
        """Test case for add_form_response_attachments

        """
        pass

    def test_add_form_response_attachments_with_identifier(self) -> None:
        """Test case for add_form_response_attachments_with_identifier

        """
        pass

    def test_create_form_response_upload_signature(self) -> None:
        """Test case for create_form_response_upload_signature

        """
        pass

    def test_create_form_response_upload_signature_with_identifier(self) -> None:
        """Test case for create_form_response_upload_signature_with_identifier

        """
        pass

    def test_create_upload_signature(self) -> None:
        """Test case for create_upload_signature

        """
        pass

    def test_delete_asset_attachment(self) -> None:
        """Test case for delete_asset_attachment

        """
        pass

    def test_delete_form_response_attachment(self) -> None:
        """Test case for delete_form_response_attachment

        """
        pass

    def test_get_asset_attachment(self) -> None:
        """Test case for get_asset_attachment

        """
        pass

    def test_get_asset_attachments(self) -> None:
        """Test case for get_asset_attachments

        """
        pass

    def test_get_form_response_attachment(self) -> None:
        """Test case for get_form_response_attachment

        """
        pass

    def test_get_form_response_attachment_with_identifier(self) -> None:
        """Test case for get_form_response_attachment_with_identifier

        """
        pass

    def test_get_form_response_attachments(self) -> None:
        """Test case for get_form_response_attachments

        """
        pass

    def test_get_form_response_attachments_with_identifier(self) -> None:
        """Test case for get_form_response_attachments_with_identifier

        """
        pass

    def test_update_asset_attachments(self) -> None:
        """Test case for update_asset_attachments

        """
        pass


if __name__ == '__main__':
    unittest.main()
