# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.models.cycle_type_response import CycleTypeResponse

class TestCycleTypeResponse(unittest.TestCase):
    """CycleTypeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CycleTypeResponse:
        """Test CycleTypeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CycleTypeResponse`
        """
        model = CycleTypeResponse()
        if include_optional:
            return CycleTypeResponse(
                id = '',
                name = '',
                description = '',
                created_at = '',
                owner_id = '',
                identifier = '',
                display_settings = skyledge_sdk.models.cycle_type_display_settings_dto.CycleTypeDisplaySettingsDto(
                    color = '', 
                    metrics = [
                        skyledge_sdk.models.cycle_type_metrics_dto.CycleTypeMetricsDto(
                            name = '', 
                            icon = '', 
                            value = '', )
                        ], 
                    start = skyledge_sdk.models.cycle_type_endpoints_dto.CycleTypeEndpointsDto(
                        title = '', 
                        description = '', ), 
                    end = skyledge_sdk.models.cycle_type_endpoints_dto.CycleTypeEndpointsDto(
                        title = '', 
                        description = '', ), )
            )
        else:
            return CycleTypeResponse(
                id = '',
                name = '',
                description = '',
                created_at = '',
                owner_id = '',
                identifier = '',
        )
        """

    def testCycleTypeResponse(self):
        """Test CycleTypeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
