# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.cycles_api import CyclesApi


class TestCyclesApi(unittest.TestCase):
    """CyclesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CyclesApi()

    def tearDown(self) -> None:
        pass

    def test_create_cycle(self) -> None:
        """Test case for create_cycle

        """
        pass

    def test_create_cycle_by_identifier(self) -> None:
        """Test case for create_cycle_by_identifier

        """
        pass

    def test_cycle_summary(self) -> None:
        """Test case for cycle_summary

        """
        pass

    def test_delete_cycle_by_id(self) -> None:
        """Test case for delete_cycle_by_id

        """
        pass

    def test_get_cycle_by_cycle_id(self) -> None:
        """Test case for get_cycle_by_cycle_id

        """
        pass

    def test_list_cycles(self) -> None:
        """Test case for list_cycles

        """
        pass

    def test_search_cycles(self) -> None:
        """Test case for search_cycles

        """
        pass

    def test_update_cycle_by_id(self) -> None:
        """Test case for update_cycle_by_id

        """
        pass


if __name__ == '__main__':
    unittest.main()
