# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.forms_api import FormsApi


class TestFormsApi(unittest.TestCase):
    """FormsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FormsApi()

    def tearDown(self) -> None:
        pass

    def test_create_form(self) -> None:
        """Test case for create_form

        """
        pass

    def test_get_form_using_form_id(self) -> None:
        """Test case for get_form_using_form_id

        """
        pass

    def test_get_form_using_form_id1(self) -> None:
        """Test case for get_form_using_form_id1

        """
        pass

    def test_get_form_using_form_identifier(self) -> None:
        """Test case for get_form_using_form_identifier

        """
        pass

    def test_get_form_using_form_identifier1(self) -> None:
        """Test case for get_form_using_form_identifier1

        """
        pass

    def test_get_responses_using_form_id(self) -> None:
        """Test case for get_responses_using_form_id

        """
        pass

    def test_get_responses_using_form_identifier(self) -> None:
        """Test case for get_responses_using_form_identifier

        """
        pass

    def test_list_forms(self) -> None:
        """Test case for list_forms

        """
        pass

    def test_update_form_response(self) -> None:
        """Test case for update_form_response

        """
        pass

    def test_update_form_response_with_identifier(self) -> None:
        """Test case for update_form_response_with_identifier

        """
        pass

    def test_update_form_using_id(self) -> None:
        """Test case for update_form_using_id

        """
        pass

    def test_update_form_using_identifier(self) -> None:
        """Test case for update_form_using_identifier

        """
        pass


if __name__ == '__main__':
    unittest.main()
