# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.cycle_types_api import CycleTypesApi


class TestCycleTypesApi(unittest.TestCase):
    """CycleTypesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CycleTypesApi()

    def tearDown(self) -> None:
        pass

    def test_create_cycle_type(self) -> None:
        """Test case for create_cycle_type

        """
        pass

    def test_get_cycle_type(self) -> None:
        """Test case for get_cycle_type

        """
        pass

    def test_list_cycle_types(self) -> None:
        """Test case for list_cycle_types

        """
        pass

    def test_update_cycle_type(self) -> None:
        """Test case for update_cycle_type

        """
        pass


if __name__ == '__main__':
    unittest.main()
