# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.rule_types_api import RuleTypesApi


class TestRuleTypesApi(unittest.TestCase):
    """RuleTypesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RuleTypesApi()

    def tearDown(self) -> None:
        pass

    def test_create_rule_type(self) -> None:
        """Test case for create_rule_type

        """
        pass

    def test_get_rule_type(self) -> None:
        """Test case for get_rule_type

        """
        pass

    def test_list_rule_types(self) -> None:
        """Test case for list_rule_types

        """
        pass

    def test_update_rule_type(self) -> None:
        """Test case for update_rule_type

        """
        pass


if __name__ == '__main__':
    unittest.main()
