# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.apps_api import AppsApi


class TestAppsApi(unittest.TestCase):
    """AppsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AppsApi()

    def tearDown(self) -> None:
        pass

    def test_install_app_to_control_room(self) -> None:
        """Test case for install_app_to_control_room

        """
        pass

    def test_list_installed_apps_for_control_room(self) -> None:
        """Test case for list_installed_apps_for_control_room

        """
        pass

    def test_list_installed_apps_for_control_room1(self) -> None:
        """Test case for list_installed_apps_for_control_room1

        """
        pass

    def test_uninstall_control_room_app(self) -> None:
        """Test case for uninstall_control_room_app

        """
        pass

    def test_update_control_room_app(self) -> None:
        """Test case for update_control_room_app

        """
        pass

    def test_update_control_room_app1(self) -> None:
        """Test case for update_control_room_app1

        """
        pass


if __name__ == '__main__':
    unittest.main()
