# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.errors_api import ErrorsApi


class TestErrorsApi(unittest.TestCase):
    """ErrorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ErrorsApi()

    def tearDown(self) -> None:
        pass

    def test_error(self) -> None:
        """Test case for error

        """
        pass

    def test_error1(self) -> None:
        """Test case for error1

        """
        pass

    def test_error2(self) -> None:
        """Test case for error2

        """
        pass

    def test_error3(self) -> None:
        """Test case for error3

        """
        pass

    def test_error4(self) -> None:
        """Test case for error4

        """
        pass

    def test_error5(self) -> None:
        """Test case for error5

        """
        pass

    def test_error6(self) -> None:
        """Test case for error6

        """
        pass


if __name__ == '__main__':
    unittest.main()
