# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.tasks_api import TasksApi


class TestTasksApi(unittest.TestCase):
    """TasksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TasksApi()

    def tearDown(self) -> None:
        pass

    def test_create_task(self) -> None:
        """Test case for create_task

        """
        pass

    def test_delete_task(self) -> None:
        """Test case for delete_task

        """
        pass

    def test_get_task(self) -> None:
        """Test case for get_task

        """
        pass

    def test_list_tasks(self) -> None:
        """Test case for list_tasks

        """
        pass

    def test_search_tasks(self) -> None:
        """Test case for search_tasks

        """
        pass

    def test_search_tasks_within_control_room(self) -> None:
        """Test case for search_tasks_within_control_room

        """
        pass

    def test_update_task(self) -> None:
        """Test case for update_task

        """
        pass


if __name__ == '__main__':
    unittest.main()
