# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.place_types_api import PlaceTypesApi


class TestPlaceTypesApi(unittest.TestCase):
    """PlaceTypesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlaceTypesApi()

    def tearDown(self) -> None:
        pass

    def test_assign_place_type_to_controlroom(self) -> None:
        """Test case for assign_place_type_to_controlroom

        """
        pass

    def test_create_place_type(self) -> None:
        """Test case for create_place_type

        """
        pass

    def test_get_place_type(self) -> None:
        """Test case for get_place_type

        """
        pass

    def test_list_place_types(self) -> None:
        """Test case for list_place_types

        """
        pass

    def test_list_place_types_for_control_room(self) -> None:
        """Test case for list_place_types_for_control_room

        """
        pass

    def test_update_place_type(self) -> None:
        """Test case for update_place_type

        """
        pass


if __name__ == '__main__':
    unittest.main()
