# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_create_users(self) -> None:
        """Test case for create_users

        """
        pass

    def test_invite_users(self) -> None:
        """Test case for invite_users

        """
        pass

    def test_list_users(self) -> None:
        """Test case for list_users

        """
        pass

    def test_retrieve_user_devices(self) -> None:
        """Test case for retrieve_user_devices

        """
        pass

    def test_retrieve_user_preferences(self) -> None:
        """Test case for retrieve_user_preferences

        """
        pass

    def test_subscribe_to_mailing_list(self) -> None:
        """Test case for subscribe_to_mailing_list

        """
        pass

    def test_unsubscribe_from_mailing_list(self) -> None:
        """Test case for unsubscribe_from_mailing_list

        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        """
        pass

    def test_update_user_device(self) -> None:
        """Test case for update_user_device

        """
        pass

    def test_update_user_preferences(self) -> None:
        """Test case for update_user_preferences

        """
        pass

    def test_verify_user(self) -> None:
        """Test case for verify_user

        """
        pass


if __name__ == '__main__':
    unittest.main()
