# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.control_rooms_api import ControlRoomsApi


class TestControlRoomsApi(unittest.TestCase):
    """ControlRoomsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ControlRoomsApi()

    def tearDown(self) -> None:
        pass

    def test_create_control_rooms(self) -> None:
        """Test case for create_control_rooms

        """
        pass

    def test_delete_control_room(self) -> None:
        """Test case for delete_control_room

        """
        pass

    def test_get_control_room(self) -> None:
        """Test case for get_control_room

        """
        pass

    def test_get_report_url(self) -> None:
        """Test case for get_report_url

        """
        pass

    def test_list_control_rooms(self) -> None:
        """Test case for list_control_rooms

        """
        pass

    def test_retrieve_configuration(self) -> None:
        """Test case for retrieve_configuration

        """
        pass

    def test_update_configuration(self) -> None:
        """Test case for update_configuration

        """
        pass

    def test_update_control_room(self) -> None:
        """Test case for update_control_room

        """
        pass


if __name__ == '__main__':
    unittest.main()
