# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.rules_api import RulesApi


class TestRulesApi(unittest.TestCase):
    """RulesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RulesApi()

    def tearDown(self) -> None:
        pass

    def test_create_rule(self) -> None:
        """Test case for create_rule

        """
        pass

    def test_create_rule_by_identifier(self) -> None:
        """Test case for create_rule_by_identifier

        """
        pass

    def test_delete_rule(self) -> None:
        """Test case for delete_rule

        """
        pass

    def test_get_rule(self) -> None:
        """Test case for get_rule

        """
        pass

    def test_list_rules(self) -> None:
        """Test case for list_rules

        """
        pass

    def test_search_rules_within_control_room(self) -> None:
        """Test case for search_rules_within_control_room

        """
        pass

    def test_update_rule(self) -> None:
        """Test case for update_rule

        """
        pass


if __name__ == '__main__':
    unittest.main()
