# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.assets_api import AssetsApi


class TestAssetsApi(unittest.TestCase):
    """AssetsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AssetsApi()

    def tearDown(self) -> None:
        pass

    def test_create_asset(self) -> None:
        """Test case for create_asset

        """
        pass

    def test_create_asset_by_identifier(self) -> None:
        """Test case for create_asset_by_identifier

        """
        pass

    def test_execute_aggregation(self) -> None:
        """Test case for execute_aggregation

        """
        pass

    def test_execute_aggregation_by_id(self) -> None:
        """Test case for execute_aggregation_by_id

        """
        pass

    def test_execute_aggregation_by_identifier(self) -> None:
        """Test case for execute_aggregation_by_identifier

        """
        pass

    def test_get_asset_using_asset_id(self) -> None:
        """Test case for get_asset_using_asset_id

        """
        pass

    def test_get_asset_using_asset_identifier(self) -> None:
        """Test case for get_asset_using_asset_identifier

        """
        pass

    def test_list_asset_attribute_values_by_attribute_name(self) -> None:
        """Test case for list_asset_attribute_values_by_attribute_name

        """
        pass

    def test_list_asset_for_control_room(self) -> None:
        """Test case for list_asset_for_control_room

        """
        pass

    def test_list_assets(self) -> None:
        """Test case for list_assets

        """
        pass

    def test_retrieve_asset_snapshot(self) -> None:
        """Test case for retrieve_asset_snapshot

        """
        pass

    def test_retrieve_location_history_for_asset(self) -> None:
        """Test case for retrieve_location_history_for_asset

        """
        pass

    def test_retrieve_location_history_for_asset1(self) -> None:
        """Test case for retrieve_location_history_for_asset1

        """
        pass

    def test_retrieve_metrics_for_asset(self) -> None:
        """Test case for retrieve_metrics_for_asset

        """
        pass

    def test_retrieve_metrics_for_asset1(self) -> None:
        """Test case for retrieve_metrics_for_asset1

        """
        pass

    def test_search_assets(self) -> None:
        """Test case for search_assets

        """
        pass

    def test_update_asset_by_id(self) -> None:
        """Test case for update_asset_by_id

        """
        pass

    def test_update_asset_by_identifier(self) -> None:
        """Test case for update_asset_by_identifier

        """
        pass


if __name__ == '__main__':
    unittest.main()
