# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.billing_api import BillingApi


class TestBillingApi(unittest.TestCase):
    """BillingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BillingApi()

    def tearDown(self) -> None:
        pass

    def test_authorize_payment_method(self) -> None:
        """Test case for authorize_payment_method

        """
        pass

    def test_get_billing_plan(self) -> None:
        """Test case for get_billing_plan

        """
        pass

    def test_get_invoices(self) -> None:
        """Test case for get_invoices

        """
        pass

    def test_get_payment_method(self) -> None:
        """Test case for get_payment_method

        """
        pass


if __name__ == '__main__':
    unittest.main()
