# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.collaborators_api import CollaboratorsApi


class TestCollaboratorsApi(unittest.TestCase):
    """CollaboratorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CollaboratorsApi()

    def tearDown(self) -> None:
        pass

    def test_invite_collaborators(self) -> None:
        """Test case for invite_collaborators

        """
        pass

    def test_list_collaborators(self) -> None:
        """Test case for list_collaborators

        """
        pass

    def test_update_control_room_collaborator(self) -> None:
        """Test case for update_control_room_collaborator

        """
        pass


if __name__ == '__main__':
    unittest.main()
