# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.places_api import PlacesApi


class TestPlacesApi(unittest.TestCase):
    """PlacesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlacesApi()

    def tearDown(self) -> None:
        pass

    def test_create_place(self) -> None:
        """Test case for create_place

        """
        pass

    def test_create_place_by_identifier(self) -> None:
        """Test case for create_place_by_identifier

        """
        pass

    def test_delete_place_by_id(self) -> None:
        """Test case for delete_place_by_id

        """
        pass

    def test_delete_place_by_identifier(self) -> None:
        """Test case for delete_place_by_identifier

        """
        pass

    def test_get_place_using_place_id(self) -> None:
        """Test case for get_place_using_place_id

        """
        pass

    def test_get_place_using_place_identifier(self) -> None:
        """Test case for get_place_using_place_identifier

        """
        pass

    def test_list_places(self) -> None:
        """Test case for list_places

        """
        pass

    def test_list_places_for_control_room(self) -> None:
        """Test case for list_places_for_control_room

        """
        pass

    def test_update_place_by_id(self) -> None:
        """Test case for update_place_by_id

        """
        pass

    def test_update_place_by_identifier(self) -> None:
        """Test case for update_place_by_identifier

        """
        pass


if __name__ == '__main__':
    unittest.main()
